==> gcc-java-3.3.6.tar.bz2: gcc-3.3.6/libjava/javax/swing/CellEditor.java <==
/* CellEditor.java --
   Copyright (C) 2002 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package javax.swing;

// Imports
import java.util.*;
import javax.swing.event.*;

/**
 * CellEditor
 * @author	Andrew Selkirk
 * @version	1.0
 */
public interface CellEditor {

	//-------------------------------------------------------------
	// Methods ----------------------------------------------------
	//-------------------------------------------------------------

	/**
	 * getCellEditorValue
	 * @returns Object
	 */
	public Object getCellEditorValue();

	/**
	 * isCellEditable
	 * @param event TODO
	 * @returns boolean
	 */
	public boolean isCellEditable(EventObject event);

	/**
	 * shouldSelectCell
	 * @param event TODO
	 * @returns boolean
	 */
	public boolean shouldSelectCell(EventObject event);

	/**
	 * stopCellEditing
	 * @returns boolean
	 */
	public boolean stopCellEditing();

	/**
	 * cancelCellEditing
	 */
	public void cancelCellEditing();

	/**
	 * addCellEditorListener
	 * @param value0 TODO
	 */
	public void addCellEditorListener(CellEditorListener listener);

	/**
	 * removeCellEditorListener
	 * @param listener TODO
	 */
	public void removeCellEditorListener(CellEditorListener listener);


} // CellEditor

==> gcc-java-4.0.3.tar.bz2: gcc-4.0.3/libjava/javax/swing/CellEditor.java <==
/* CellEditor.java --
   Copyright (C) 2002, 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.swing;

import java.util.EventObject;

import javax.swing.event.CellEditorListener;

/**
 * CellEditor
 * @author	Andrew Selkirk
 * @version	1.0
 */
public interface CellEditor
{
  /**
   * getCellEditorValue
   * @returns Object
   */
  Object getCellEditorValue();

  /**
   * isCellEditable
   * @param event TODO
   * @returns boolean
   */
  boolean isCellEditable(EventObject event);

  /**
   * shouldSelectCell
   * @param event TODO
   * @returns boolean
   */
  boolean shouldSelectCell(EventObject event);

  /**
   * stopCellEditing
   * @returns boolean
   */
  boolean stopCellEditing();

  /**
   * cancelCellEditing
   */
  void cancelCellEditing();

  /**
   * addCellEditorListener
   * @param value0 TODO
   */
  void addCellEditorListener(CellEditorListener listener);

  /**
   * removeCellEditorListener
   * @param listener TODO
   */
  void removeCellEditorListener(CellEditorListener listener);

} // CellEditor
